==> discord.js-basic-3.2.3.tgz: package/README.md <==

# Discord.js Basic

This Project Is Made To Facilitate Discord.js And Making Bots Not For Profit

## Install

Download the module with NPM Help

```bash 
  npm install discord.js-basic
```
    
## Features

- Button
- Select Menus
- Modals
- All Client Events(Slash Commands Included)

  
## Usage/Examples

```javascript
const { $client, $event, $messageSend } = require("discord.js-basic")
// Let's Create a Discord Client
const client = new $client({
    intents: [3276799]//Fill Here According To Your Bot's Intent Requests All intents = 3276799 If You Want To Find Intents, Check Out https://discord-intents-calculator.vercel.app/ 
})
//Now Let's Create an Event 
$event(client, "messageCreate", async (message) => {
    //The client specified in the event must be the client of your bot
    //give a reaction to bot now
    if(message.content === "ping") {
        //By Receiving Message Content, We Check If The Text Is ping if true we make it continue 
     $sendMessage("Pong!", message.channel) //We Get the $messageSend Function, Then We Enter Our Parameters In It, The Process Is Over. So When We Write ping, Our Bot is Pong! He will answer
    
    }
})
//Finally We Make Our Bot Login To The Client 
client.login("YOUR-BOT-TOKEN")
```

  
## Environment Variables

In order to run your bot without errors, you must fill in the following values ​​according to yourself.

`BOT-TOKEN`

`CLIENT INTENTS`

  
## Feedback


If you have any feedback, please contact us via our [Discord Address](https://discord.gg/uptime).

  
## Associated Projects

Here are the related projects

[Discord.js](https://npmjs.com/discord.js)

  
## Using Communities 

This project is used by the following Communities:

- Coming Soon
- Coming Soon

==> discord.js-basic-3.2.4.tgz: package/README.md <==

# Discord.js Basic

This Project Is Made To Facilitate Discord.js And Making Bots Not For Profit

## Install

Download the module with NPM Help

```bash 
  npm install discord.js-basic
```
    
## Features

- Button
- Select Menus
- Modals
- All Client Events(Slash Commands Included)

  
## Usage/Examples

```javascript
const { $client, $event, $sendMessage } = require("discord.js-basic")
// Let's Create a Discord Client
const client = new $client({
    intents: [3276799]//Fill Here According To Your Bot's Intent Requests All intents = 3276799 If You Want To Find Intents, Check Out https://discord-intents-calculator.vercel.app/ 
})
//Now Let's Create an Event 
$event(client, "messageCreate", async (message) => {
    //The client specified in the event must be the client of your bot
    //give a reaction to bot now
    if(message.content === "ping") {
        //By Receiving Message Content, We Check If The Text Is ping if true we make it continue 
     $sendMessage("Pong!", message.channel) //We Get the $sendMessage Function, Then We Enter Our Parameters In It, The Process Is Over. So When We Write ping, Our Bot is Pong! He will answer
    
    }
})
//Finally We Make Our Bot Login To The Client 
client.login("YOUR-BOT-TOKEN")
```

  
## Environment Variables

In order to run your bot without errors, you must fill in the following values ​​according to yourself.

`BOT-TOKEN`

`CLIENT INTENTS`

  
## Feedback


If you have any feedback, please contact us via our [Discord Address](https://discord.gg/uptime).

  
## Associated Projects

Here are the related projects

[Discord.js](https://npmjs.com/discord.js)

  
## Using Communities 

This project is used by the following Communities:

- Coming Soon
- Coming Soon
